@@ -6,12 +6,15 @@ class RollingWindow:
     """
     Process data as a rolling window
     """
-    def __init__(self, depth):
+    def __init__(self, depth, shift=1):
         """
         :param depth: how many samples will form a single window
+        :param shift: how many samples to skip between windows
         """
         assert depth > 1, "depth MUST be greater than 1"
-        self.depth = depth
+        assert shift > 0, "shift MUST be greater than 0"
+        self.depth = int(depth)
+        self.shift = int(shift)
         self.input_dim = None
 
     def fit(self, X):
@@ -30,6 +33,7 @@ class RollingWindow:
         w = np.arange(self.depth)
         t = np.arange(len(X) - self.depth + 1)
         idx = (w + t.reshape((-1, 1)))
+        idx = idx[::self.shift]
         return X[idx].reshape((-1, self.input_dim * self.depth))
 
     def port(self, class_name='RollingWindow'):
